@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: op.c,v 3.6 2003/07/12 07:22:34 shuu Exp shuu $
+ *  $Id: op.c,v 3.10 2004/09/12 08:01:52 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -9,13 +9,13 @@
 
 #include	"murasaki.h"
 
-struct mu_op mu_op = {
-	flag: FLAG_NONE,
+mu_op_t mu_op = {
+	flag: FLAG_BEEP,
+	msg_level: MU_MSG_STD,
 	device: generic,
 	device_name: MU_ARG_GENERIC,
 	command: MU_MURASAKI "." MU_ARG_GENERIC,
-	mappath: NULL,
-	default_mapname: NULL,
+	mappath: {NULL,NULL,NULL,NULL},
 	action: ACTION_NONE,
 	config: NULL,
 	sysfs: NULL,
