@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: id.c,v 1.3 2003/05/17 20:37:07 shuu Exp shuu $
+ *  $Id: id.c,v 1.5 2004/09/12 08:02:32 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -12,7 +12,7 @@
 #include	"murasaki_ieee1394.h"
 
 int
-get_id_ieee1394(struct mu_op *opp)
+get_id_ieee1394(mu_op_t *opp)
 {
 	char *ptr;
 	MU_ieee1394_config_t *config;
@@ -21,14 +21,18 @@ get_id_ieee1394(struct mu_op *opp)
 
 	ptr = getenv("VENDOR_ID");
 	config->vendor = strtoul(ptr,NULL,16);
+	LOG_OPP_DESC("VENDOR_ID=0x%x",config->vendor);
 /*
 	Now, "GUID_ID" is not available
 	ptr = getenv("GUID_ID");
 */
 	ptr = getenv("SPECIFIER_ID");
 	config->specifier = strtoul(ptr,NULL,16);
+	LOG_OPP_DESC("SPECIFIER_ID=0x%x",config->specifier);
+
 	ptr = getenv("VERSION");
 	config->version = strtoul(ptr,NULL,16);
+	LOG_OPP_DESC("VERSION=0x%x",config->version);
 	
 	return GOOD;	
 }
