@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: match.c,v 1.7 2003/08/10 03:59:39 shuu Exp shuu $
+ *  $Id: match.c,v 1.12 2004/09/12 08:03:30 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -51,18 +51,32 @@ real_match(MU_ieee1394_config_t *active,MU_ieee1394_config_t *map)
 	return GOOD;
 }
 
-int
-match_config(char **list,char **except_list,char *start,char *end,void *conf)
+
+/*
+ * called if msg_level >= MU_MSG_STD
+ */
+static void
+print_matching(MU_ieee1394_config_t *map,char *module)
 {
-	MU_ieee1394_config_t *config = conf;
-	MU_ieee1394_config_t map;
-	char *ptr,*module,*module_start,*module_end = NULL;
+	syslog(LOG_LEVEL, "MATCH(%s) -> match_flag:0x%x vendor:0x%x model:0x%x specifier:0x%x version:0x%x",
+		module,
+		map->match_flags,
+		map->vendor,
+		map->model,
+		map->specifier,
+		map->version);
+}
+
+int
+match_config(mu_op_t *opp,char *start,char *end)
+{
+	MU_ieee1394_config_t *config = opp->config,map;
+	char *ptr,*module,*module_start;
 	int status = ST_MODULE;
 	unsigned int module_len = 0,value,i;
 	char *fwdp;
-	int mod_count = 0;
 
-	DPRINTF(LOG_LEVEL,"vendor:0x%x specifier:0x%x version:0x%x",
+	LOG_OPP_DESC("vendor:0x%x specifier:0x%x version:0x%x",
 		config->vendor,
 		config->specifier,
 		config->version);
@@ -86,19 +100,14 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 					goto error_return;
 				ptr++;
 			}
-			module_end = ptr;
-			module_len = module_end - module_start;
+			/* ptr == next to module end */
+			module_len = ptr - module_start;
 			/*
 			 * check excepted modules
 			 */
-			for (i = 0;except_list[i] != NULL;i++) {
-				if (memcmp(except_list[i],module_start,module_len) == 0 && except_list[i][module_len] == '\0') {
-					break;
-				}
-			}
-			if (except_list[i] != NULL) {
+			if ((i = find_mem_list(&(opp->except_list),module_start,ptr)) != NOT_FOUND) {
 				status = ST_COMMENT;
-				syslog(LOG_LEVEL,"%s was skipped in ieee1394map",except_list[i]);
+				LOG_OPP_STD("%s was skipped in ieee1394map",opp->except_list.list[i]);
 				continue;
 			}
 		} else {
@@ -125,6 +134,7 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 				map.specifier = value;
 				break;
 			case ST_VERSION:
+				status = ST_MODULE;
 				map.version = value;
 				if (config->match_flags &
 					(config->match_flags == map.match_flags))
@@ -133,22 +143,14 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 					/* for exclusive */
 					config->match_flags = map.match_flags;
 
-					module = malloc(module_len+1);
+					module = alloc_module(module_start,module_len);
 					if (module == NULL)
 						goto error_return;
-					memcpy(module,module_start,module_len);
-					module[module_len] = '\0';
 
-					syslog(LOG_LEVEL, "MATCH(%s) -> match_flag:0x%x vendor:0x%x model:0x%x specifier:0x%x version:0x%x",
-						module,
-						map.match_flags,
-						map.vendor,
-						map.model,
-						map.specifier,
-						map.version);
-					if (add_to_list(list,module,LIST_MAX) == INVALID)
+					if (opp->msg_level >= MU_MSG_STD)
+						print_matching(&map,module);
+					if (add_to_list(&(opp->module_list),module,opp->msg_level) == INVALID)
 						goto error_return;
-					mod_count++;
 				}
 				continue;
 			default:
@@ -157,7 +159,8 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 		}
 		status++;
 	}
-	return mod_count;
+
+	return GOOD;
 
 error_return:
 	return INVALID;
