@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: op.c,v 1.5 2003/05/17 20:37:33 shuu Exp shuu $
+ *  $Id: op.c,v 1.9 2004/09/12 08:03:47 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -13,7 +13,7 @@
 MU_ieee1394_config_t config;
 
 static int
-get_info_ieee1394(struct mu_op *opp)
+get_info_ieee1394(mu_op_t *opp)
 {
 	if (get_id_ieee1394(opp) == INVALID)	/* always GOOD */
 		return INVALID;
@@ -21,13 +21,13 @@ get_info_ieee1394(struct mu_op *opp)
 	return GOOD;
 }
 
-struct mu_op mu_op = {
-	flag: FLAG_NONE,
+mu_op_t mu_op = {
+	flag: FLAG_BEEP,
+	msg_level: MU_MSG_STD,
 	device: ieee1394,
 	device_name: MU_ARG_IEEE1394,
 	command: MU_MURASAKI "." MU_ARG_IEEE1394,
-	mappath: MU_CONF_DIR "/" MU_IEEE1394MAP,
-	default_mapname: MU_DEFAULT_IEEE1394MAP,
+	mappath: {MU_CONF_DIR "/" MU_IEEE1394MAP,MU_DEFAULT_IEEE1394MAP,NULL,NULL},
 	action: ACTION_NONE,
 	config: &config,
 	sysfs: NULL,
