@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: print.c,v 1.2 2003/05/17 20:35:33 shuu Exp shuu $
+ *  $Id: print.c,v 1.3 2004/09/12 08:04:00 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -12,9 +12,9 @@
 #include	"murasaki_ieee1394.h"
 
 void
-print_config(void *conf)
+print_config(mu_op_t *opp)
 {
-	MU_ieee1394_config_t *config = conf;
+	MU_ieee1394_config_t *config = opp->config;
 
 	config->match_flags = 0;
 	if (config->vendor != 0)
@@ -31,7 +31,8 @@ print_config(void *conf)
 	if (config->version != 0)
 		config->match_flags |= IEEE1394_MATCH_VERSION;
 
-	syslog(LOG_LEVEL,"MODULE 0x%08x 0x%06x 0x%06x 0x%06x 0x%06x",
+	
+	LOG_OPP_STD("MODULE 0x%08x 0x%06x 0x%06x 0x%06x 0x%06x",
 		config->match_flags,
 		config->vendor,
 		config->model,
@@ -40,12 +41,12 @@ print_config(void *conf)
 }
 
 void
-inform_config(void *conf)
+inform_config(mu_op_t *opp)
 {
-	MU_ieee1394_config_t *config = conf;
+	MU_ieee1394_config_t *config = opp->config;
 
 	/* ignore guid */
-	syslog(LOG_LEVEL, "vendor:0x%x specifier:0x%x version:0x%x",
+	LOG_OPP_STD("vendor:0x%x specifier:0x%x version:0x%x",
 		config->vendor,
 		config->specifier,
 		config->version);
