@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: env.h,v 1.6 2003/08/10 04:02:38 shuu Exp shuu $
+ *  $Id: env.h,v 1.10 2004/02/19 00:46:04 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -25,18 +25,25 @@
 #define ARG_OFF		0
 #define ARG_ON		1
 
-#define	DEBUG_NONE	0
-#define	DEBUG_TRACE	1
-#define	DEBUG_DESC	2
+#define	MU_MSG_NONE	0
+#define	MU_MSG_QUIET	1
+#define	MU_MSG_WHISPER	2
+#define	MU_MSG_STD	5
+#define	MU_MSG_TRACE	7
+#define	MU_MSG_DESC	10
+#define	MU_MSG_MIN	MU_MSG_NONE
+#define	MU_MSG_MAX	MU_MSG_DESC
 
 #define MSG_OFF		0
 #define MSG_ON		1
 
+#define	WAIT_OFF	0
+#define	WAIT_ON		1
+
 #define PRECALL		0
 #define POSTCALL	1
 
-#define FOUND		1
-#define NOT_FOUND	0
+#define NOT_FOUND	-1
 
 #endif	/* _MURASAKI_ENV_H */
 
