@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *	$Id: murasaki_ieee1394.h,v 1.3 2003/05/17 20:42:40 shuu Exp shuu $
+ *	$Id: murasaki_ieee1394.h,v 1.4 2004/02/06 00:21:36 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -26,6 +26,6 @@ typedef struct {
 	unsigned int version;
 } MU_ieee1394_config_t;
 
-extern int get_id_ieee1394(struct mu_op *);
+extern int get_id_ieee1394(mu_op_t *);
 
 #endif	/* _MURASAKI_IEEE1394_H */
