@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: murasaki_pci.h,v 1.4 2003/08/13 05:51:39 shuu Exp shuu $
+ *  $Id: murasaki_pci.h,v 1.6 2004/02/06 00:22:54 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -29,13 +29,13 @@ typedef struct {
 	char *slot;
 } MU_pci_config_t;
 
-extern int get_id_pci_class(struct mu_op *);
-extern int get_id_pci_id(struct mu_op *);
-extern int get_id_pci_slot(struct mu_op *);
+extern int get_id_pci_class(mu_op_t *);
+extern int get_id_pci_id(mu_op_t *);
+extern int get_id_pci_slot(mu_op_t *);
 /* sysfs */
-extern int get_sysfs_class(struct mu_op *);
-extern int get_sysfs_vendor(struct mu_op *);
-extern int get_sysfs_device(struct mu_op *);
-extern int sysfs_init(struct mu_op *);
+extern int get_sysfs_class(mu_op_t *);
+extern int get_sysfs_vendor(mu_op_t *);
+extern int get_sysfs_device(mu_op_t *);
+extern int sysfs_init(mu_op_t *);
 
 #endif	/* _MURASAKI_PCI_H */
