@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: action.c,v 3.7 2003/07/12 07:15:09 shuu Exp shuu $
+ *  $Id: action.c,v 3.9 2004/09/12 07:27:18 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -12,7 +12,7 @@
 #include	"murasaki.h"
 
 int
-get_action(struct mu_op *opp)
+get_action(mu_op_t *opp)
 {
 	char *ptr;
 
@@ -23,13 +23,14 @@ get_action(struct mu_op *opp)
 	/* common action pattern in 2.4 and 2.5 */
 	if (strcmp(ptr,"add") == 0 || strcmp(ptr,"register") == 0) {
 		opp->action = ACTION_ADD;
-		syslog(LOG_LEVEL,"%s device is %sed",opp->device_name,ptr);
+		LOG_OPP_STD("%s device is %sed",opp->device_name,ptr);
 		return GOOD;
 	} else if (strcmp(ptr,"remove") == 0 || strcmp(ptr,"unregister") == 0) {
 		opp->action = ACTION_REMOVE;
-		syslog(LOG_LEVEL,"%s device is %sd",opp->device_name,ptr);
+		LOG_OPP_STD("%s device is %sd",opp->device_name,ptr);
 		return GOOD;
 	}
+
 	return INVALID;
 }
 
