@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: beep.c,v 3.4 2003/05/17 20:53:41 shuu Exp shuu $
+ *  $Id: beep.c,v 3.5 2004/09/12 07:27:38 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  *  beep function is based on beep() in cardmgr.c(pcmcia-cs)
@@ -31,7 +31,7 @@ beep(int status,int flag)
 	char *beep;
 
 	if ((beep = getenv("MURASAKI_BEEP")) != NULL) {
-		if (strcmp(beep,"off") == 0) 
+		if (strcasecmp(beep,"off") == 0) 
 			return;
 	} else if (!FLAG_CHECK(flag,FLAG_BEEP)) {
 		return;
