@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: filelist.c,v 1.3 2003/09/25 05:26:10 shuu Exp shuu $
+ *  $Id: filelist.c,v 1.6 2004/09/12 07:39:01 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -25,30 +25,30 @@ enum string_status {ST_START, ST_IN };
 
 /*
  * "list" is allocated, so Don't forget free "list[0]".
+ * list[last] == NULL, so arg 3 max need to be list count + 1
  */
 int
-list_from_file(char *fname,char **list,int max)
+list_from_file(char *fname,list_t *lst)
 {
 	char *buf,*ptr;
-	int count,sum;
+	int size;
 	enum string_status status = ST_START;
-#ifdef	DEBUG
-	int i;
-#endif
 
-	if ((buf = alloc_read(fname,&sum)) == NULL || sum == 0) {
-		list[0] = NULL;	/* end mark */
-		return 0;
+	if ((buf = alloc_read(fname,&size)) == NULL || size == 0) {
+		if (lst->size > 0) {
+			lst->list[0] = NULL;	/* end mark:not used */
+			lst->used = 0;
+		}
+		return GOOD;
 	}
 
-	for (ptr = buf,count = 0;ptr < buf + sum;ptr++) {
+	for (ptr = buf,lst->used = 0;ptr < buf + size;ptr++) {
 		if (status == ST_START) {
-			if (count == max) {
-				syslog(LOG_LEVEL,"%s list is overflow(max %d).",
-					fname,max);
-				break;	/* report count of list */
+			if (lst->used == lst->size) {
+				if (realloc_list(lst) == INVALID)
+					return INVALID;
 			}
-			list[count++] = ptr;
+			lst->list[lst->used++] = ptr;
 			status = ST_IN;
 		} else {
 			if (*ptr == CHAR_RSEP) {
@@ -57,12 +57,7 @@ list_from_file(char *fname,char **list,int max)
 			}
 		}
 	}
-	list[count] = NULL;	/* end mark */
-#ifdef	DEBUG
-	for (i = 0;i < count;i++) {
-		syslog(LOG_LEVEL,"buf[%d] \"%s\"",i,list[i]);
-	}
-#endif
+	lst->list[lst->used] = NULL;	/* end mark:not used */
 
-	return count;
+	return GOOD;
 }
