@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: value.c,v 1.2 2003/08/10 04:06:34 shuu Exp shuu $
+ *  $Id: value.c,v 1.5 2004/09/12 07:51:06 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -18,7 +18,7 @@
 #define	XVALUE_LEN	12	/* 32bits */
 
 int
-sysfs_value(char *fname,unsigned int *ret,int base,int max_sleep)
+sysfs_value(char *fname,unsigned int *ret,int base,int max_sleep,int msg_level)
 {
 	int fd;
 	char buf[XVALUE_LEN+1];
@@ -28,22 +28,22 @@ sysfs_value(char *fname,unsigned int *ret,int base,int max_sleep)
 	for(sleep_count = 0;sleep_count < max_sleep;sleep_count++) {
 		if (access(fname,R_OK) != -1)
 			break;
-		DPRINTF(LOG_LEVEL,"sysfs_value sleep %d",sleep_count);
+		LOG(MU_MSG_TRACE,msg_level,"sysfs_value %s: sleep %d",fname,sleep_count);
 		sleep(1);
 	}
 
 	if ((fd = open(fname,O_RDONLY)) == -1) {
-		DPRINTF(LOG_LEVEL,"open error \"%s\"",fname);
+		LOG(MU_MSG_TRACE,msg_level,"open error \"%s\": %m",fname);
 		return INVALID;
 	}
 	if ((len = read(fd,buf,XVALUE_LEN)) <= 0) {
-		DPRINTF(LOG_LEVEL,"read error \"%s\"",fname);
+		LOG(MU_MSG_TRACE,msg_level,"read error \"%s\": %m",fname);
 		return INVALID;
 	}
 	close(fd);
 	buf[len] = '\0';
 	*ret = strtoul(buf,NULL,base);
-	DPRINTF(LOG_LEVEL,"%s=%d 0x%x",fname,*ret,*ret);
+	LOG(MU_MSG_TRACE,msg_level,"%s=%d 0x%x",fname,*ret,*ret);
 
 	return GOOD;
 }
