@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: class.c,v 1.2 2003/05/17 21:01:51 shuu Exp shuu $
+ *  $Id: class.c,v 1.5 2004/09/12 07:59:11 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -15,12 +15,12 @@
  * format: x
  */
 int
-get_id_pci_class(struct mu_op *opp)
+get_id_pci_class(mu_op_t *opp)
 {
 	char *ptr;
 	MU_pci_config_t *config;
 
-	config = (MU_pci_config_t *)opp->config;
+	config = opp->config;
 
 	ptr = getenv("PCI_CLASS");
 	if (ptr == NULL)
@@ -28,7 +28,7 @@ get_id_pci_class(struct mu_op *opp)
 
 	config->class = strtoul(ptr,NULL,16);
 	config->class_mask = 0;	/* not used */
-	DPRINTF(LOG_LEVEL,"class 0x%x",config->class);
+	LOG_OPP_DESC("class 0x%x",config->class);
 
 	return GOOD;
 }
