@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: id.c,v 1.2 2003/05/17 21:01:30 shuu Exp shuu $
+ *  $Id: id.c,v 1.5 2004/09/12 07:59:36 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -23,25 +23,23 @@ get_id_sub(MU_pci_id_t *id,char *ptr)
 	char *sep;
 
 	id->vendor = strtoul(ptr,&sep,16);
-	DPRINTF(LOG_LEVEL,"vendor 0x%x",id->vendor);
 	if (*sep != SEP)
 		return INVALID;
 
 	ptr = sep + 1;
 	id->device = strtoul(ptr,NULL,16);
-	DPRINTF(LOG_LEVEL,"device 0x%x",id->device);
 	
 	return GOOD;
 }
 
 int
-get_id_pci_id(struct mu_op *opp)
+get_id_pci_id(mu_op_t *opp)
 {
 	char *ptr;
 	MU_pci_id_t id;
 	MU_pci_config_t *config;
 
-	config = (MU_pci_config_t *)opp->config;
+	config = opp->config;
 
 	ptr = getenv("PCI_ID");
 	if (ptr == NULL)
@@ -49,13 +47,16 @@ get_id_pci_id(struct mu_op *opp)
 	if(get_id_sub(&id,ptr) != GOOD)		/* returns must be GOOD */
 		return INVALID;
 	config->id = id;
-
+	LOG_OPP_DESC("vendor 0x%x device 0x%x",
+		id.vendor,id.device);
 	ptr = getenv("PCI_SUBSYS_ID");
 	if (ptr == NULL)
 		return INVALID;
 	if(get_id_sub(&id,ptr) != GOOD)		/* returns must be GOOD */
 		return INVALID;
 	config->sub_id = id;
+	LOG_OPP_DESC("subvendor 0x%x subdevice 0x%x",
+		id.vendor,id.device);
 
 	return GOOD;
 }
