@@ -1,9 +1,12 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: match.c,v 1.3 2003/08/10 04:16:45 shuu Exp shuu $
+ *  $Id: match.c,v 1.7 2004/09/12 08:00:12 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
+ *
+ * Fix: matching invalid value
+ *			Shun-ichi TAHARA <jado@flowernet.gr.jp>
  */
 #include	<stdio.h>
 #include	<string.h>
@@ -31,35 +34,44 @@
 static int
 real_match(MU_pci_config_t *active,MU_pci_config_t *map)
 {
-	if (active->id.vendor || active->sub_id.vendor || active->class_mask) {
-        if ((map->id.vendor == PCI_ANY_ID || active->id.vendor == map->id.vendor) &&
-            (map->id.device == PCI_ANY_ID || active->id.device == map->id.device) &&
-            (map->sub_id.vendor == PCI_ANY_ID || active->sub_id.vendor == map->sub_id.vendor) &&
-            (map->sub_id.device == PCI_ANY_ID || active->sub_id.device == map->sub_id.device) &&
-			(active->class & map->class_mask) == map->class)
+	if (!active->id.vendor && !active->sub_id.vendor && !active->class)
+		return INVALID;
+	if (active->id.vendor &&
+	    ((map->id.vendor != PCI_ANY_ID && active->id.vendor != map->id.vendor) ||
+	     (map->id.device != PCI_ANY_ID && active->id.device != map->id.device)))
+		return INVALID;
+	if (active->sub_id.vendor &&
+	    ((map->sub_id.vendor != PCI_ANY_ID && active->sub_id.vendor != map->sub_id.vendor) ||
+	     (map->sub_id.device != PCI_ANY_ID && active->sub_id.device != map->sub_id.device)))
+		return INVALID;
+	if (active->class && (active->class & map->class_mask) != map->class)
+		return INVALID;
 
-		return GOOD;
-	}
-	return INVALID;
+	return GOOD;
+}
+
+/*
+ * called if msg_level >= MU_MSG_STD
+ */
+static void
+print_matching(MU_pci_config_t *map,char *module)
+{
+	syslog(LOG_LEVEL,"MATCH(%s) -> vendor:0x%x device:0x%x subvendor:0x%x subdevice 0x%x class:0x%x class_mask:0x%x",
+		module,
+		map->id.vendor,map->id.device,
+		map->sub_id.vendor,map->sub_id.device,
+		map->class,map->class_mask);
 }
 
 int
-match_config(char **list,char **except_list,char *start,char *end,void *conf)
+match_config(mu_op_t *opp,char *start,char *end)
 {
-	MU_pci_config_t *config = conf;
-	MU_pci_config_t map;
-	char *ptr,*module,*module_start,*module_end = NULL;
+	MU_pci_config_t *config = opp->config,map;
+	char *ptr,*module,*module_start;
 	int status = ST_MODULE;
 	unsigned int value,module_len = 0,i;
 	char *fwdp;
-	int mod_count = 0;
 
-#if 0
-	DPRINTF(LOG_LEVEL,"match_config:vendor:0x%x device:0x%x subvendor:0x%x subdevice 0x%x class:0x%x class_mask:0x%x(ignore)",
-		config->id.vendor,config->id.device,
-		config->sub_id.vendor,config->sub_id.device,
-		config->class,config->class_mask);
-#endif
 	for(module_start = ptr = start; ptr < end;ptr++) {
 		if (status == ST_COMMENT) {
 			while(*ptr != CHAR_RSEP) {
@@ -80,19 +92,14 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 					goto error_return;
 				ptr++;
 			}
-			module_end = ptr;
-			module_len = module_end - module_start;
+			/* ptr == next to module end */
+			module_len = ptr - module_start;
 			/*
 			 * check excepted modules
 			 */
-			for (i = 0;except_list[i] != NULL;i++) {
-				if (memcmp(except_list[i],module_start,module_len) == 0 && except_list[i][module_len] == '\0') {
-					break;
-				}
-			}
-			if (except_list[i] != NULL) {
+			if ((i = find_mem_list(&(opp->except_list),module_start,ptr)) != NOT_FOUND) {
 				status = ST_COMMENT;
-				syslog(LOG_LEVEL,"%s was skipped in pcimap",except_list[i]);
+				LOG_OPP_STD("%s was skipped in pcimap",opp->except_list.list[i]);
 				continue;
 			}
 		} else {
@@ -120,19 +127,13 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 			case ST_DRIVER_DATA:	/* ignore */
 				status = ST_MODULE;
 				if (real_match(config,&map) == GOOD) {
-					module = malloc(module_len+1);
+					module = alloc_module(module_start,module_len);
 					if (module == NULL)
 						goto error_return;
-					memcpy(module,module_start,module_len);
-					module[module_len] = '\0';
-					syslog(LOG_LEVEL,"MATCH(%s) -> vendor:0x%x device:0x%x subvendor:0x%x subdevice 0x%x class:0x%x class_mask:0x%x",
-						module,
-						map.id.vendor,map.id.device,
-						map.sub_id.vendor,map.sub_id.device,
-						map.class,map.class_mask);
-					if (add_to_list(list,module,LIST_MAX) == INVALID)
+					if (opp->msg_level >= MU_MSG_STD)
+						print_matching(&map,module);
+					if (add_to_list(&(opp->module_list),module,opp->msg_level) == INVALID)
 						goto error_return;
-					mod_count++;
 				}
 				continue;
 			default:
@@ -141,7 +142,8 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 		}
 		status++;
 	}
-	return mod_count;
+
+	return GOOD;
 
 error_return:
 	return INVALID;
