@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: op.c,v 1.4 2003/05/17 20:59:30 shuu Exp shuu $
+ *  $Id: op.c,v 1.8 2004/09/12 08:00:31 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -13,7 +13,7 @@
 MU_pci_config_t config;
 
 static int
-get_info_pci(struct mu_op *opp)
+get_info_pci(mu_op_t *opp)
 {
 	if (FLAG_CHECK(opp->flag,FLAG_SYSFS) && opp->devpath != NULL) {
 		if (sysfs_init(opp) == INVALID)
@@ -35,13 +35,13 @@ get_info_pci(struct mu_op *opp)
 }
 
 
-struct mu_op mu_op = {
-	flag: FLAG_NONE,
+mu_op_t mu_op = {
+	flag: FLAG_BEEP,
+	msg_level: MU_MSG_STD,
 	device: pci,
 	device_name: MU_ARG_PCI,
 	command: MU_MURASAKI "." MU_ARG_PCI,
-	mappath: MU_CONF_DIR "/" MU_PCIMAP,
-	default_mapname: MU_DEFAULT_PCIMAP,
+	mappath: {MU_CONF_DIR "/" MU_PCIMAP,MU_DEFAULT_PCIMAP,NULL,NULL},
 	action: ACTION_NONE,
 	config: &config,
 	sysfs: NULL,
