@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: match.c,v 3.9 2003/08/10 04:23:10 shuu Exp shuu $
+ *  $Id: match.c,v 3.13 2004/09/12 07:54:09 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -40,15 +40,6 @@ real_match(MU_usb_config_t *active,MU_usb_config_t *map)
 		return INVALID;
 	if (map->match_flags == 0) /* umm... */
 		return INVALID;
-#ifdef	DEBUG_ALL
-	DPRINTF(LOG_LEVEL,"match_flags:0x%x vendor:0x%x product:0x%x Dclass:0x%x Dsubclass:0x%x Dprotocol:0x%x Iclass:0x%x Isubclass:0x%x Iprotocol:0x%x",
-	map->match_flags,
-	map->product.vendor, map->product.product,
-	map->device.class, map->device.subclass,
-	map->device.protocol,
-	map->interface.class, map->interface.subclass,
-	map->interface.protocol);
-#endif
 
 	/* Vendor */
 	if ((map->match_flags & USB_DEVICE_ID_MATCH_VENDOR) &&
@@ -90,18 +81,32 @@ real_match(MU_usb_config_t *active,MU_usb_config_t *map)
 	return GOOD;
 }
 
-int
-match_config(char **list,char **except_list,char *start,char *end,void *conf)
+/*
+ * called if msg_level >= MU_MSG_STD
+ */
+static void
+print_matching(MU_usb_config_t *map,char *module)
 {
-	MU_usb_config_t *config = conf;
+
+	syslog(LOG_LEVEL,"MATCH(%s) -> match_flags:0x%x vendor:0x%x product:0x%x Dclass:0x%x Dsubclass:0x%x Dprotocol:0x%x Iclass:0x%x Isubclass:0x%x Iprotocol:0x%x",
+		module,map->match_flags,
+		map->product.vendor,map->product.product,
+		map->device.class,map->device.subclass,map->device.protocol,
+		map->interface.class,map->interface.subclass,
+		map->interface.protocol);
+}
+
+int
+match_config(mu_op_t *opp,char *start,char *end)
+{
+	MU_usb_config_t *config = opp->config;
 	MU_usb_config_t map;
-	char *ptr,*module,*module_start,*module_end = NULL;
+	char *ptr,*module,*module_start;
 	int status = ST_MODULE;
 	unsigned int module_len = 0,value,i;
 	char *fwdp;
-	int mod_count = 0;
 
-	DPRINTF(LOG_LEVEL,"vendor:0x%x product:0x%x device:0x%x Dclass:0x%x Dsubclass:0x%x Dprotocol:0x%x Iclass:0x%x Isubclass:0x%x Iprotocol:0x%x",
+	LOG_OPP_DESC("vendor:0x%x product:0x%x device:0x%x Dclass:0x%x Dsubclass:0x%x Dprotocol:0x%x Iclass:0x%x Isubclass:0x%x Iprotocol:0x%x",
 		config->product.vendor, config->product.product,
 		config->product.device_lo,
 		config->device.class, config->device.subclass,
@@ -128,19 +133,14 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 					goto error_return;
 				ptr++;
 			}
-			module_end = ptr;
-			module_len = module_end - module_start;
+			/* ptr == next to module end */
+			module_len = ptr - module_start;
 			/*
 			 * check excepted modules
 			 */
-			for (i = 0;except_list[i] != NULL;i++) {
-				if (memcmp(except_list[i],module_start,module_len) == 0 && except_list[i][module_len] == '\0') {
-					break;
-				}
-			}
-			if (except_list[i] != NULL) {
+			if ((i = find_mem_list(&(opp->except_list),module_start,ptr)) != NOT_FOUND) {
 				status = ST_COMMENT;
-				syslog(LOG_LEVEL,"%s was skipped in usbmap",except_list[i]);
+				LOG_OPP_STD("%s was skipped in usbmap",opp->except_list.list[i]);
 				continue;
 			}
 		} else {
@@ -189,22 +189,14 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 				if (real_match(config,&map) == GOOD) {
 					/* for exclusive */
 					config->match_flags = map.match_flags;
-					module = malloc(module_len+1);
+
+					module = alloc_module(module_start,module_len);
 					if (module == NULL)
 						goto error_return;
-					memcpy(module,module_start,module_len);
-					module[module_len] = '\0';
-
-					syslog(LOG_LEVEL,"MATCH(%s) -> match_flags:0x%x vendor:0x%x product:0x%x Dclass:0x%x Dsubclass:0x%x Dprotocol:0x%x Iclass:0x%x Isubclass:0x%x Iprotocol:0x%x",
-					module,map.match_flags,
-					map.product.vendor,map.product.product,
-					map.device.class,map.device.subclass,map.device.protocol,
-					map.interface.class,map.interface.subclass,
-					map.interface.protocol);
-
-					if (add_to_list(list,module,LIST_MAX) == INVALID)
+					if (opp->msg_level >= MU_MSG_STD)
+						print_matching(&map,module);
+					if (add_to_list(&(opp->module_list),module,opp->msg_level) == INVALID)
 						goto error_return;
-					mod_count++;
 				}
 				continue;
 			default:
@@ -213,7 +205,8 @@ match_config(char **list,char **except_list,char *start,char *end,void *conf)
 		}
 		status++;
 	}
-	return mod_count;
+
+	return GOOD;
 
 error_return:
 	return INVALID;
