@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: op.c,v 3.6 2003/05/17 21:06:24 shuu Exp shuu $
+ *  $Id: op.c,v 3.10 2004/09/12 07:54:31 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -13,7 +13,7 @@
 static MU_usb_config_t config;
 
 static int
-get_info_usb(struct mu_op *opp)
+get_info_usb(mu_op_t *opp)
 {
 	if (FLAG_CHECK(opp->flag,FLAG_SYSFS) && opp->devpath != NULL) {
 		switch(get_sysfs_kind(opp)) {
@@ -40,13 +40,13 @@ get_info_usb(struct mu_op *opp)
 	return GOOD;
 }
 
-struct mu_op mu_op = {
-	flag: FLAG_NONE,
+mu_op_t mu_op = {
+	flag: FLAG_BEEP,
+	msg_level: MU_MSG_STD,
 	device: usb,
 	device_name: MU_ARG_USB,
 	command: MU_MURASAKI "." MU_ARG_USB,
-	mappath: MU_CONF_DIR "/" MU_USBMAP,
-	default_mapname: MU_DEFAULT_USBMAP,
+	mappath: {MU_CONF_DIR "/" MU_USBMAP,MU_DEFAULT_USBMAP,NULL,NULL},
 	action: ACTION_NONE,
 	config: &config,
 	sysfs: NULL,
