@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: product.c,v 3.6 2003/05/17 21:06:01 shuu Exp shuu $
+ *  $Id: product.c,v 3.9 2004/09/12 07:57:46 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -18,7 +18,7 @@
  */
 
 int
-get_id_usb_product(struct mu_op *opp)
+get_id_usb_product(mu_op_t *opp)
 {
 	char *ptr;
 	char *sep;
@@ -36,19 +36,19 @@ get_id_usb_product(struct mu_op *opp)
 	}
 	
 	config->product.vendor = strtoul(ptr,&sep,16);	/* vendor */
-	DPRINTF(LOG_LEVEL,"vender 0x%x\n",config->product.vendor);
+	LOG_OPP_DESC("vender 0x%x",config->product.vendor);
 	if (*sep != SEP)
 		return INVALID;
 
 	ptr = sep + 1;
 	config->product.product = strtoul(ptr,&sep,16);	/* product */
-	DPRINTF(LOG_LEVEL,"product 0x%x\n",config->product.product);
+	LOG_OPP_DESC("product 0x%x",config->product.product);
 	if (*sep != SEP)
 		return INVALID;
 
 	ptr = sep + 1;
 	config->product.device_lo = strtoul(ptr,NULL,16);	/* device */
-	DPRINTF(LOG_LEVEL,"device(_lo) 0x%x\n",config->product.device_lo);
+	LOG_OPP_DESC("device 0x%x",config->product.device_lo);
 
 	return GOOD;	
 }
